<?php

function diagnostic_tool_menu() {
    add_menu_page(
        '診断コンテンツジェネレータ',
        '診断コンテンツジェネレータ',
        'manage_options',
        'diagnostic-tool',
        'diagnostic_tool_admin_page',
        'dashicons-admin-generic',
        6
    );

    add_submenu_page(
        'diagnostic-tool',
        '新しい診断を追加',
        '新しい診断を追加',
        'manage_options',
        'add-diagnostic',
        'diagnostic_tool_add_new_page'
    );

    add_submenu_page(
        'diagnostic-tool',
        '診断の管理',
        '診断の管理',
        'manage_options',
        'manage-diagnostics',
        'diagnostic_tool_manage_page'
    );

    add_submenu_page(
        null,
        '設問の管理',
        '設問の管理',
        'manage_options',
        'manage-questions',
        'diagnostic_tool_manage_questions_page'
    );
}

add_action( 'admin_menu', 'diagnostic_tool_menu' );

function diagnostic_tool_admin_page() {
    echo '<div class="wrap"><h1>診断コンテンツジェネレータへようこそ</h1><p>サブメニューから診断を追加・管理できます。</p>';
    echo '<h2>使い方</h2>';
    echo '<p>1. 「新しい診断を追加」から新しい診断を作成します。</p>';
    echo '<p>2. 「診断の管理」から作成した診断の設問・回答・結果を設定します。</p>';
    echo '<h2>注意書き</h2>';
    echo '<p>このプラグインの動作保証は行っておりません。カスタマイズや修正を希望の場合は、<a href="https://wk-partners.co.jp/homepage/contact/" target="_blank">株式会社ウェブ企画パートナーズ</a>までお問い合わせください。</p></div>';
}

function diagnostic_tool_add_new_page() {
    if (isset($_POST['diagnostic_name'])) {
        global $wpdb;
        $table_name = $wpdb->prefix . 'diagnostic_tool';
        $wpdb->insert($table_name, ['name' => sanitize_text_field($_POST['diagnostic_name'])]);
        echo '<div class="updated"><p>診断が作成されました！<a href="'.admin_url('admin.php?page=manage-diagnostics').'">診断の管理</a>より、設問・回答・結果の設定をおこなってください。</p></div>';
    }
    ?>
    <div class="wrap">
        <h1>新しい診断を作成</h1>
        <form method="post" action="">
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">診断名</th>
                    <td><input type="text" name="diagnostic_name" required /></td>
                </tr>
            </table>
            <?php submit_button('診断を作成'); ?>
        </form>
    </div>
    <?php
}

function diagnostic_tool_manage_page() {
    global $wpdb;
    $diagnostics_table = $wpdb->prefix . 'diagnostic_tool';

    if (isset($_POST['delete_diagnostic'])) {
        $diagnostic_id = intval($_POST['delete_diagnostic']);
        $wpdb->delete($diagnostics_table, ['id' => $diagnostic_id]);
        echo '<div class="updated"><p>診断が削除されました。</p></div>';
    }

    $diagnostics = $wpdb->get_results("SELECT * FROM $diagnostics_table");
    ?>
    <div class="wrap">
        <h1>診断の管理</h1>
        <table class="wp-list-table widefat fixed striped">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>診断名</th>
                    <th>ショートコード</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($diagnostics as $diagnostic) : ?>
                    <tr>
                        <td><?php echo esc_html($diagnostic->id); ?></td>
                        <td><?php echo esc_html($diagnostic->name); ?></td>
                        <td>[diagnostic_tool id="<?php echo esc_html($diagnostic->id); ?>"]</td>
                        <td>
                            <form method="post" action="" style="display:inline;">
                                <input type="hidden" name="delete_diagnostic" value="<?php echo esc_attr($diagnostic->id); ?>">
                                <input type="submit" value="削除" class="button button-danger" onclick="return confirm('本当に削除しますか？')">
                            </form>
                            <a href="<?php echo admin_url('admin.php?page=manage-questions&diagnostic_id=' . $diagnostic->id); ?>" class="button">設問を管理</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
    <?php
}
?>
