<?php

function diagnostic_tool_create_tables() {
    global $wpdb;
    $charset_collate = $wpdb->get_charset_collate();

    $diagnostics_table = $wpdb->prefix . 'diagnostic_tool';
    $questions_table = $wpdb->prefix . 'diagnostic_tool_questions';
    $answers_table = $wpdb->prefix . 'diagnostic_tool_answers';
    $results_table = $wpdb->prefix . 'diagnostic_tool_results';

    $sql = "CREATE TABLE $diagnostics_table (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        name tinytext NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;

    CREATE TABLE $questions_table (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        diagnostic_id mediumint(9) NOT NULL,
        question_text text NOT NULL,
        PRIMARY KEY  (id),
        FOREIGN KEY (diagnostic_id) REFERENCES $diagnostics_table(id) ON DELETE CASCADE
    ) $charset_collate;

    CREATE TABLE $answers_table (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        question_id mediumint(9) NOT NULL,
        answer_text text NOT NULL,
        points smallint NOT NULL,
        PRIMARY KEY  (id),
        FOREIGN KEY (question_id) REFERENCES $questions_table(id) ON DELETE CASCADE
    ) $charset_collate;

    CREATE TABLE $results_table (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        diagnostic_id mediumint(9) NOT NULL,
        min_score smallint NOT NULL,
        max_score smallint NOT NULL,
        result_url text NOT NULL,
        PRIMARY KEY  (id),
        FOREIGN KEY (diagnostic_id) REFERENCES $diagnostics_table(id) ON DELETE CASCADE
    ) $charset_collate;";

    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
    dbDelta( $sql );
}

add_action('wp_ajax_diagnostic_tool_get_result', 'diagnostic_tool_get_result');
add_action('wp_ajax_nopriv_diagnostic_tool_get_result', 'diagnostic_tool_get_result');

function diagnostic_tool_get_result() {
    global $wpdb;

    $diagnostic_id = intval($_GET['diagnostic_id']);
    $score = intval($_GET['score']);

    $result = $wpdb->get_row($wpdb->prepare(
        "SELECT result_url FROM {$wpdb->prefix}diagnostic_tool_results WHERE diagnostic_id = %d AND min_score <= %d AND max_score >= %d",
        $diagnostic_id, $score, $score
    ));

    if ($result) {
        wp_send_json_success(['url' => $result->result_url]);
    } else {
        wp_send_json_error(['message' => 'うまく診断できませんでした']);
    }
}
?>
