<?php

function diagnostic_tool_manage_questions_page() {
    global $wpdb;
    $diagnostic_id = intval($_GET['diagnostic_id']);
    $questions_table = $wpdb->prefix . 'diagnostic_tool_questions';
    $answers_table = $wpdb->prefix . 'diagnostic_tool_answers';
    $results_table = $wpdb->prefix . 'diagnostic_tool_results';

    // 新しい設問の追加
    if (isset($_POST['new_question'])) {
        $wpdb->insert($questions_table, [
            'diagnostic_id' => $diagnostic_id,
            'question_text' => sanitize_text_field($_POST['new_question'])
        ]);
        echo '<div class="updated"><p>新しい設問が追加されました。</p></div>';
    }

    // 設問の更新
    if (isset($_POST['edit_question_id'])) {
        $wpdb->update($questions_table, [
            'question_text' => sanitize_text_field($_POST['edit_question_text'])
        ], ['id' => intval($_POST['edit_question_id'])]);
        echo '<div class="updated"><p>設問が更新されました。</p></div>';
    }

    // 新しい回答の追加
    if (isset($_POST['new_answer'])) {
        $wpdb->insert($answers_table, [
            'question_id' => intval($_POST['question_id']),
            'answer_text' => sanitize_text_field($_POST['new_answer']),
            'points' => intval($_POST['points'])
        ]);
        echo '<div class="updated"><p>新しい回答が追加されました。</p></div>';
    }

    // 回答の更新
    if (isset($_POST['edit_answer_id'])) {
        $wpdb->update($answers_table, [
            'answer_text' => sanitize_text_field($_POST['edit_answer_text']),
            'points' => intval($_POST['edit_points'])
        ], ['id' => intval($_POST['edit_answer_id'])]);
        echo '<div class="updated"><p>回答が更新されました。</p></div>';
    }

    // 設問の削除
    if (isset($_POST['delete_question'])) {
        $wpdb->delete($questions_table, ['id' => intval($_POST['delete_question'])]);
        echo '<div class="updated"><p>設問が削除されました。</p></div>';
    }

    // 回答の削除
    if (isset($_POST['delete_answer'])) {
        $wpdb->delete($answers_table, ['id' => intval($_POST['delete_answer'])]);
        echo '<div class="updated"><p>回答が削除されました。</p></div>';
    }

    // 結果URLの追加
    if (isset($_POST['result_url'])) {
        $min_score = intval($_POST['min_score']);
        $max_score = intval($_POST['max_score']);
        $result_url = sanitize_text_field($_POST['result_url']);

        $wpdb->insert($results_table, [
            'diagnostic_id' => $diagnostic_id,
            'min_score' => $min_score,
            'max_score' => $max_score,
            'result_url' => $result_url
        ]);
        echo '<div class="updated"><p>結果のURLが追加されました。</p></div>';
    }

    // 結果URLの更新
    if (isset($_POST['edit_result_id'])) {
        $wpdb->update($results_table, [
            'min_score' => intval($_POST['edit_min_score']),
            'max_score' => intval($_POST['edit_max_score']),
            'result_url' => sanitize_text_field($_POST['edit_result_url'])
        ], ['id' => intval($_POST['edit_result_id'])]);
        echo '<div class="updated"><p>結果のURLが更新されました。</p></div>';
    }

    // 結果URLの削除
    if (isset($_POST['delete_result'])) {
        $wpdb->delete($results_table, ['id' => intval($_POST['delete_result'])]);
        echo '<div class="updated"><p>結果のURLが削除されました。</p></div>';
    }

    $questions = $wpdb->get_results($wpdb->prepare("SELECT * FROM $questions_table WHERE diagnostic_id = %d", $diagnostic_id));
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM $results_table WHERE diagnostic_id = %d", $diagnostic_id));
    ?>
    <div class="wrap">
        <h1>設問と回答の管理 (診断ID: <?php echo $diagnostic_id; ?>)</h1>
        
        <form method="post" action="">
            <h2>新しい設問を追加</h2>
            <input type="text" name="new_question" required>
            <?php submit_button('設問を追加'); ?>
        </form>
        
        <?php foreach ($questions as $question) : ?>
            <div class="question-block">
                <h3><?php echo esc_html($question->question_text); ?></h3>
                <form method="post" action="" style="display:inline;">
                    <input type="hidden" name="delete_question" value="<?php echo esc_attr($question->id); ?>">
                    <input type="submit" value="設問を削除" class="button button-danger" onclick="return confirm('本当に削除しますか？')">
                </form>
                <button type="button" class="button" onclick="toggleEditForm('edit-question-<?php echo $question->id; ?>')">編集</button>
                
                <form id="edit-question-<?php echo $question->id; ?>" method="post" action="" style="display:none;">
                    <input type="hidden" name="edit_question_id" value="<?php echo esc_attr($question->id); ?>">
                    <input type="text" name="edit_question_text" value="<?php echo esc_attr($question->question_text); ?>" required>
                    <?php submit_button('設問を更新'); ?>
                </form>
                
                <form method="post" action="">
                    <h4>新しい回答を追加</h4>
                    <input type="hidden" name="question_id" value="<?php echo esc_attr($question->id); ?>">
                    <input type="text" name="new_answer" required>
                    <input type="number" name="points" required>
                    <?php submit_button('回答を追加'); ?>
                </form>
                
                <?php
                $answers = $wpdb->get_results($wpdb->prepare("SELECT * FROM $answers_table WHERE question_id = %d", $question->id));
                foreach ($answers as $answer) : ?>
                    <div>
                        <span><?php echo esc_html($answer->answer_text); ?> (<?php echo esc_html($answer->points); ?>点)</span>
                        <form method="post" action="" style="display:inline;">
                            <input type="hidden" name="delete_answer" value="<?php echo esc_attr($answer->id); ?>">
                            <input type="submit" value="回答を削除" class="button button-danger" onclick="return confirm('本当に削除しますか？')">
                        </form>
                        <button type="button" class="button" onclick="toggleEditForm('edit-answer-<?php echo $answer->id; ?>')">編集</button>
                        
                        <form id="edit-answer-<?php echo $answer->id; ?>" method="post" action="" style="display:none;">
                            <input type="hidden" name="edit_answer_id" value="<?php echo esc_attr($answer->id); ?>">
                            <input type="text" name="edit_answer_text" value="<?php echo esc_attr($answer->answer_text); ?>" required>
                            <input type="number" name="edit_points" value="<?php echo esc_attr($answer->points); ?>" required>
                            <?php submit_button('回答を更新'); ?>
                        </form>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endforeach; ?>

        <h2>診断結果URLの追加</h2>
        <form method="post" action="">
            <input type="hidden" name="diagnostic_id" value="<?php echo $diagnostic_id; ?>">
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">最小スコア</th>
                    <td><input type="number" name="min_score" required /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">最大スコア</th>
                    <td><input type="number" name="max_score" required /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">結果URL</th>
                    <td><input type="url" name="result_url" required /></td>
                </tr>
            </table>
            <?php submit_button('結果URLを追加'); ?>
        </form>

        <h2>診断結果URLの管理</h2>
        <table class="wp-list-table widefat fixed striped">
            <thead>
                <tr>
                    <th>最小スコア</th>
                    <th>最大スコア</th>
                    <th>結果URL</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($results as $result) : ?>
                    <tr>
                        <td><?php echo esc_html($result->min_score); ?></td>
                        <td><?php echo esc_html($result->max_score); ?></td>
                        <td><?php echo esc_html($result->result_url); ?></td>
                        <td>
                            <form method="post" action="" style="display:inline;">
                                <input type="hidden" name="delete_result" value="<?php echo esc_attr($result->id); ?>">
                                <input type="submit" value="削除" class="button button-danger" onclick="return confirm('本当に削除しますか？')">
                            </form>
                            <button type="button" class="button" onclick="toggleEditForm('edit-result-<?php echo $result->id; ?>')">編集</button>
                            
                            <form id="edit-result-<?php echo $result->id; ?>" method="post" action="" style="display:none;">
                                <input type="hidden" name="edit_result_id" value="<?php echo esc_attr($result->id); ?>">
                                <input type="number" name="edit_min_score" value="<?php echo esc_attr($result->min_score); ?>" required>
                                <input type="number" name="edit_max_score" value="<?php echo esc_attr($result->max_score); ?>" required>
                                <input type="url" name="edit_result_url" value="<?php echo esc_attr($result->result_url); ?>" required>
                                <?php submit_button('結果URLを更新'); ?>
                            </form>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
    <script>
        function toggleEditForm(id) {
            var form = document.getElementById(id);
            if (form.style.display === "none") {
                form.style.display = "block";
            } else {
                form.style.display = "none";
            }
        }
    </script>
    <?php
}
?>
