<?php

function diagnostic_tool_display_quiz( $diagnostic_id ) {
    global $wpdb;

    $questions = $wpdb->get_results(
        $wpdb->prepare("SELECT * FROM {$wpdb->prefix}diagnostic_tool_questions WHERE diagnostic_id = %d", $diagnostic_id)
    );

    if ( empty( $questions ) ) {
        return '<p>No questions found for this diagnostic.</p>';
    }

    ob_start();
    ?>
    <div class="diagnostic-quiz">
        <form id="diagnostic-quiz-form">
            <?php foreach ( $questions as $question ) : ?>
                <div class="question">
                    <h5><?php echo esc_html( $question->question_text ); ?></h5>
                    <?php
                    $answers = $wpdb->get_results(
                        $wpdb->prepare("SELECT * FROM {$wpdb->prefix}diagnostic_tool_answers WHERE question_id = %d", $question->id)
                    );
                    foreach ( $answers as $answer ) : ?>
                        <div>
                            <input type="radio" name="q<?php echo $question->id; ?>" value="<?php echo esc_attr( $answer->points ); ?>"> <?php echo esc_html( $answer->answer_text ); ?>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endforeach; ?>
            <button type="button" class="btn btn-primary" onclick="calculateResult()">結果を見る</button>
        </form>
        <div id="diagnostic-result" class="result alert alert-info" style="display:none;"></div>
    </div>
    <script>
        function calculateResult() {
            let score = 0;
            const form = document.getElementById('diagnostic-quiz-form');
            const formData = new FormData(form);

            formData.forEach((value, key) => {
                score += parseInt(value);
            });

            // Get results from the server
            fetch('<?php echo admin_url( 'admin-ajax.php' ); ?>?action=diagnostic_tool_get_result&diagnostic_id=<?php echo $diagnostic_id; ?>&score=' + score)
                .then(response => response.json())
                .then(data => {
                    const resultDiv = document.getElementById('diagnostic-result');
                    if (data.success) {
                        window.location.href = data.data.url;
                    } else {
                        resultDiv.textContent = 'うまく診断できませんでした';
                        resultDiv.style.display = 'block';
                    }
                });
        }
    </script>
    <?php
    return ob_get_clean();
}
?>
